@@ -6,16 +6,22 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Acme::Mitey::Cards::Mite";
-    our $MITE_VERSION = "0.006012";
+    our $MITE_VERSION = "0.007003";
 
     BEGIN {
-        *bare  = \&Acme::Mitey::Cards::Mite::bare;
-        *false = \&Acme::Mitey::Cards::Mite::false;
-        *lazy  = \&Acme::Mitey::Cards::Mite::lazy;
-        *ro    = \&Acme::Mitey::Cards::Mite::ro;
-        *rw    = \&Acme::Mitey::Cards::Mite::rw;
-        *rwp   = \&Acme::Mitey::Cards::Mite::rwp;
-        *true  = \&Acme::Mitey::Cards::Mite::true;
+        require Scalar::Util;
+        *bare    = \&Acme::Mitey::Cards::Mite::bare;
+        *blessed = \&Scalar::Util::blessed;
+        *carp    = \&Acme::Mitey::Cards::Mite::carp;
+        *confess = \&Acme::Mitey::Cards::Mite::confess;
+        *croak   = \&Acme::Mitey::Cards::Mite::croak;
+        *false   = \&Acme::Mitey::Cards::Mite::false;
+        *guard   = \&Acme::Mitey::Cards::Mite::guard;
+        *lazy    = \&Acme::Mitey::Cards::Mite::lazy;
+        *ro      = \&Acme::Mitey::Cards::Mite::ro;
+        *rw      = \&Acme::Mitey::Cards::Mite::rw;
+        *rwp     = \&Acme::Mitey::Cards::Mite::rwp;
+        *true    = \&Acme::Mitey::Cards::Mite::true;
     }
 
     BEGIN {
@@ -45,9 +51,8 @@
                       and $args->{"deck"}->isa(q[Acme::Mitey::Cards::Deck]);
                 }
               )
-              or Acme::Mitey::Cards::Mite::croak
-              "Type check failed in constructor: %s should be %s", "deck",
-              "Deck";
+              or croak "Type check failed in constructor: %s should be %s",
+              "deck", "Deck";
             $self->{"deck"} = $args->{"deck"};
         }
         require Scalar::Util && Scalar::Util::weaken( $self->{"deck"} )
@@ -63,15 +68,13 @@
                       or ref( \( my $val = $args->{"reverse"} ) ) eq 'SCALAR';
                 }
               }
-              or Acme::Mitey::Cards::Mite::croak
-              "Type check failed in constructor: %s should be %s", "reverse",
-              "Str";
+              or croak "Type check failed in constructor: %s should be %s",
+              "reverse", "Str";
             $self->{"reverse"} = $args->{"reverse"};
         }
 
         # Attribute: suit
-        Acme::Mitey::Cards::Mite::croak "Missing key in constructor: suit"
-          unless exists $args->{"suit"};
+        croak "Missing key in constructor: suit" unless exists $args->{"suit"};
         do {
             my $coerced_value = do {
                 my $to_coerce = $args->{"suit"};
@@ -111,14 +114,13 @@
                       and $coerced_value->isa(q[Acme::Mitey::Cards::Suit]);
                 }
               )
-              or Acme::Mitey::Cards::Mite::croak
-              "Type check failed in constructor: %s should be %s", "suit",
-              "Suit";
+              or croak "Type check failed in constructor: %s should be %s",
+              "suit", "Suit";
             $self->{"suit"} = $coerced_value;
         };
 
         # Attribute: number
-        Acme::Mitey::Cards::Mite::croak "Missing key in constructor: number"
+        croak "Missing key in constructor: number"
           unless exists $args->{"number"};
         do {
             my $coerced_value = do {
@@ -166,9 +168,8 @@
                   && ( $coerced_value >= 1 )
                   && ( $coerced_value <= 10 )
               )
-              or Acme::Mitey::Cards::Mite::croak
-              "Type check failed in constructor: %s should be %s", "number",
-              "CardNumber";
+              or croak "Type check failed in constructor: %s should be %s",
+              "number", "CardNumber";
             $self->{"number"} = $coerced_value;
         };
 
@@ -176,7 +177,7 @@
         my @unknown = grep not(/\A(?:deck|number|reverse|suit)\z/),
           keys %{$args};
         @unknown
-          and Acme::Mitey::Cards::Mite::croak(
+          and croak(
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
@@ -210,8 +211,7 @@
     else {
         *number = sub {
             @_ > 1
-              ? Acme::Mitey::Cards::Mite::croak(
-                "number is a read-only attribute of @{[ref $_[0]]}")
+              ? croak("number is a read-only attribute of @{[ref $_[0]]}")
               : $_[0]{"number"};
         };
     }
@@ -226,11 +226,38 @@
     else {
         *suit = sub {
             @_ > 1
-              ? Acme::Mitey::Cards::Mite::croak(
-                "suit is a read-only attribute of @{[ref $_[0]]}")
+              ? croak("suit is a read-only attribute of @{[ref $_[0]]}")
               : $_[0]{"suit"};
         };
     }
 
+    our %SIGNATURE_FOR;
+
+    $SIGNATURE_FOR{"number_or_a"} = sub {
+        my $__NEXT__ = shift;
+
+        my ( %tmp, $tmp, @head );
+
+        @_ == 1
+          or croak(
+            "Wrong number of parameters in signature for %s: %s, got %d",
+            "number_or_a", "expected exactly 1 parameters",
+            scalar(@_)
+          );
+
+        @head = splice( @_, 0, 1 );
+
+        # Parameter $head[0] (type: Defined)
+        ( defined( $head[0] ) )
+          or croak(
+            "Type check failed in signature for number_or_a: %s should be %s",
+            "\$_[0]", "Defined" );
+
+        return ( &$__NEXT__( @head, @_ ) );
+    };
+
+    $SIGNATURE_FOR{"to_string"} =
+      $Acme::Mitey::Cards::Card::SIGNATURE_FOR{"to_string"};
+
     1;
 }
